@@ -7,7 +7,7 @@
 **
 ** Modified for use with prerex:
 ** http://www.ctan.org/tex-archive/graphics/prerex
-** Copyright (C) 2009-11 R. D. Tennent 
+** Copyright (C) 2009-12 R. D. Tennent 
 ** School of Computing, Queen's University, rdt@cs.queensu.ca 
 
 ** This program is free software; you can redistribute it and/or modify it
@@ -81,7 +81,7 @@ void DocumentWidget::mousePressEvent(QMouseEvent *event)
         QString URI = link->url();
         QRectF linkRect = pageLinks[i]->linkArea();
         if ( linkRect.contains(mousePos) &&  URI.startsWith(QString("coord:")) )
-            {   // clicked in a coord: x,y box
+            {   // clicked in a coord: x,y box or coord: x0,y0,x1,y1 bullet
                 QString cbString;
                 if ( qtm == Qt::RightButton )
                 {
