@@ -7,7 +7,7 @@
 **
 ** Modified for use with prerex:
 ** http://www.ctan.org/tex-archive/graphics/prerex
-** Copyright (C) 2009-11 R. D. Tennent 
+** Copyright (C) 2009-12 R. D. Tennent 
 ** School of Computing, Queen's University, rdt@cs.queensu.ca 
 
 ** This program is free software; you can redistribute it and/or modify it
@@ -25,13 +25,24 @@
 ** 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 **
 ****************************************************************************/
-
 #include <QtGui>
 #include "window.h"
 
 
 # include <QString>
 # include <QStringList>
+# include <QThread>
+
+#include <qthread.h>
+
+class mythread : public QThread
+{
+public:
+        static void sleep(unsigned long secs) {
+                QThread::sleep(secs);
+        }
+};
+
 
 Window::Window(QWidget *parent)
     : QMainWindow(parent)
@@ -114,15 +125,15 @@ void Window::loadDocument(void)
    pdfFileInfo.setFile(pdfFilePath);
    while ( pdfFileInfo.size() == 0 ) 
    { // wait for the PDF file 
-        sleep (1);
+        mythread::sleep (1);
         pdfFileInfo.refresh();
    }
-   sleep (2);
+   mythread::sleep (2);
    sb->showMessage(pdfFilePath);
    fsw->addPath(pdfFilePath);
    while ( !(documentWidget->setDocument(pdfFilePath)) ) 
    { // if at first you don't succeed, try, try again 
-     sleep (1);
+     mythread::sleep (1);
    }    
    scaleComboBox->setEnabled(true);
    pageSpinBox->setEnabled(true);
